@@ -1,10 +1,12 @@
 import argparse
+import json
 import logging
 import sys
 
 from pathlib import Path
 
 from numiner import __version__
+from numiner.classes.converter import Converter
 from numiner.classes.letter import Letter
 from numiner.classes.sheet import Sheet
 
@@ -23,7 +25,7 @@ def existing_path(arg):
     if path.exists() and (path.is_dir() or path.is_file()):
         return path
     raise argparse.ArgumentTypeError(
-        "Either couldn't find or it's neither a directory nor a file. Check and try again."
+        f"{arg} - Either couldn't find or it's neither a directory nor a file. Check and try again."
     )
 
 
@@ -36,7 +38,33 @@ def existing_json_file(arg):
 
 def create_argparser():
     parser = argparse.ArgumentParser(allow_abbrev=False)
+    subparser = parser.add_subparsers()
+
+    converter_parser = subparser.add_parser("convert", help="Help convert")
+    converter_parser.add_argument(
+        "-p",
+        "--paths",
+        nargs=2,
+        metavar=("<src>", "<dest>"),
+        required=True,
+        type=existing_path,
+        help="source and destination paths",
+    )
+    converter_parser.add_argument(
+        "size", metavar="SIZE", type=int, help="number of images that each class contains"
+    )
+    converter_parser.add_argument(
+        "ratio", metavar="RATIO", help="test, train or percentage of the test data",
+    )
     parser.add_argument("-v", "--version", action="version", version=f"%(prog)s {__version__}")
+    parser.add_argument(
+        "--labels",
+        dest="labels",
+        metavar="<path>",
+        type=existing_json_file,
+        help="a path to .json file that's holding top to bottom, left to right labels of the sheet with their ids",
+    )
+    parser.add_argument("--clean", dest="cleaning", metavar=("<path>"), type=existing_path)
     parser.add_argument(
         "-s",
         "--sheet",
@@ -55,13 +83,6 @@ def create_argparser():
         help="a path to a folder or a file that's holding the cropped image(s) &\
              a path to a folder where all <result> images will be saved",
     )
-    parser.add_argument(
-        "-c",
-        dest="labels",
-        metavar="<path>",
-        type=existing_json_file,
-        help="a path to .json file that's holding top to bottom, left to right labels of the sheet with their ids",
-    )
     return parser
 
 
@@ -122,12 +143,40 @@ def handle_config(arg):
     return Sheet._CHARACTER_SEQUENCE
 
 
+def handle_cleaning(arg):
+    stat = {}
+
+    for dir, label in ((subdir, subdir.stem) for subdir in arg.iterdir() if subdir.is_dir()):
+        for id, img in enumerate(
+            tuple(img for img in dir.iterdir() if img.suffix in (".png", ".jpg"))
+        ):
+            target = img.parent / Path(f"{label}_{id}{img.suffix}")
+            img.rename(target)
+
+        length = len(tuple(dir.iterdir()))
+        stat[label] = length
+        print(f"[~] {label}: {length} images")
+
+    if not (stat_path := arg / "stat.json").exists():
+        stat_path.touch()
+
+    with open(stat_path, "w") as stat_file:
+        json.dump(stat, stat_file)
+
+
 def handle_empty_args(args, parser):
     if len(tuple(value for key, value in vars(args).items() if value is None)) == len(vars(args)):
         parser.print_help()
         sys.exit()
 
 
+def handle_conversion(args):
+    (src, dst), size, ratio = args
+    if src.exists() and dst.exists() and size and ratio:
+        return Converter.process(src, dst, size=size, ratio=ratio)
+    sys.exit()
+
+
 def get_version():
     print(__version__)
 
@@ -147,6 +196,15 @@ def main():
     if args.letter:
         handle_letter(args.letter)
 
+    if args.cleaning:
+        handle_cleaning(args.cleaning)
+
+    try:
+        if args.paths:
+            handle_conversion((args.paths, args.size, args.ratio))
+    except AttributeError:
+        pass
+
 
 if __name__ == "__main__":
     main()
